@@ -1,5 +1,5 @@
 /******************************************************************************
-* Copyright 1996-2013 United States Government as represented by the
+* Copyright 1996-2014 United States Government as represented by the
 * Administrator of the National Aeronautics and Space Administration.
 * All Rights Reserved.
 ******************************************************************************/
@@ -55,6 +55,8 @@
 *                               Added a new error message.
 *   V3.11 29-May-12, M Liu      Added CDFinsertVarRecordsByVarID and
 *                               CDFinsertVarRecorsByVarName.
+*   V3.12 28-May-14, M Liu      Added function items for record deletion:
+*                               r/zVAR__RECORDS_RENUMBER_.
 ******************************************************************************/
 
 #if !defined(CDFh_INCLUDEd__)
@@ -301,6 +303,7 @@ static double *TT2000NULL = 0;
 #define MULTI_FILE_FORMAT		((CDFstatus) 1007)
 #define SOME_ALREADY_ALLOCATED		((CDFstatus) 1008)
 #define PRECEEDING_RECORDS_ALLOCATED	((CDFstatus) 1009)
+#define TT2000_CDF_MAYNEEDUPDATE        ((CDFstatus) 1010)
 
 #define CDF_OK                          ((CDFstatus) 0)
 
@@ -437,6 +440,8 @@ static double *TT2000NULL = 0;
 #define ZLIB_COMPRESS_ERROR             ((CDFstatus) (-2231))
 #define ZLIB_UNCOMPRESS_ERROR           ((CDFstatus) (-2232))
 #define CANNOT_INSERT_RECORDS           ((CDFstatus) (-2233))
+#define TT2000_USED_OUTDATED_TABLE      ((CDFstatus) (-2234))
+#define BADDATE_LEAPSECOND_UPDATED      ((CDFstatus) (-2235))
 
 /******************************************************************************
 * Functions (for INTERNAL interface).
@@ -624,6 +629,9 @@ static double *TT2000NULL = 0;
 #define STAGE_CACHESIZE_	154L
 #define COMPRESS_CACHESIZE_	155L
 #define CDF_CHECKSUM_           156L
+#define rVAR_RECORDS_RENUMBER_	157L
+#define zVAR_RECORDS_RENUMBER_	158L
+#define CDF_LEAPSECONDLASTUPDATED_ 159L
 
 #define CDFwithSTATS_		200L	/* For CDF internal use only! */
 #define CDF_ACCESS_		201L	/* For CDF internal use only! */
@@ -764,6 +772,9 @@ CDFgetAttrEntryNumElements(id,3,attrNum,entryNum,numElems)
 #define CDFdeletezVarRecords(id,varNum,sRec,eRec) \
 CDFdeleteVarRecords(id,1,varNum,sRec,eRec)
 
+#define CDFdeletezVarRecordsRenumber(id,varNum,sRec,eRec) \
+CDFdeleteVarRecordsRenumber(id,1,varNum,sRec,eRec)
+
 #define CDFgetzVarName(id,varNum,varName) \
 CDFgetVarName(id,1,varNum,varName)
 
@@ -1061,6 +1072,13 @@ CDFlib (SELECT_, CDF_, id, \
         DELETE_, (zVar? zVAR_RECORDS_: rVAR_RECORDS_), firstRec, lastRec, \
         NULL_)
 
+#define CDFdeleteVarRecordsRenumber(id,zVar,varNum,firstRec,lastRec) \
+CDFlib (SELECT_, CDF_, id, \
+                 (zVar? zVAR_: rVAR_), varNum, \
+        DELETE_, (zVar? zVAR_RECORDS_RENUMBER_: rVAR_RECORDS_RENUMBER_), \
+                  firstRec, lastRec, \
+        NULL_)
+
 /*
  * GET_ *
  *      */
@@ -1097,6 +1115,11 @@ CDFlib (SELECT_, CDF_, id, \
         GET_, CDF_FORMAT_, format, \
         NULL_)
 
+#define CDFgetLeapSecondLastUpdated(id,lastUpdated) \
+CDFlib (SELECT_, CDF_, id, \
+        GET_, CDF_LEAPSECONDLASTUPDATED_, lastUpdated, \
+        NULL_)
+
 #define CDFgetCompressionInfo(name,cType,cParms,cSize,uSize) \
 CDFlib (GET_, CDF_INFO_, name, cType, cParms, cSize, uSize, \
         NULL_)
@@ -1385,6 +1408,11 @@ CDFlib (SELECT_, CDF_, id, \
         PUT_, CDF_FORMAT_, format, \
         NULL_)
 
+#define CDFsetLeapSecondLastUpdated(id,lastUpdated) \
+CDFlib (SELECT_, CDF_, id, \
+        PUT_, CDF_LEAPSECONDLASTUPDATED_, lastUpdated, \
+        NULL_)
+
 #define CDFsetMajority(id,majority) \
 CDFlib (SELECT_, CDF_, id, \
         PUT_, CDF_MAJORITY_, majority, \
@@ -1726,14 +1754,17 @@ VISIBLE_PREFIX CDFstatus CDFgetVarRangeRecordsByVarName PROTOARGs((
   CDFid id, char *varName, long startRec, long stopRec, void *buffer
 ));
 VISIBLE_PREFIX CDFstatus CDFputVarRangeRecordsByVarName PROTOARGs((
-  CDFid id, char *varName, long startRec,long stopRec, void *buffer
+  CDFid id, char *varName, long startRec, long stopRec, void *buffer
 ));
 VISIBLE_PREFIX CDFstatus CDFinsertVarRecordsByVarID PROTOARGs((
   CDFid id, int zVar, long varNum, long startRec,long numRecs,
   void *buffer
 ));
 VISIBLE_PREFIX CDFstatus CDFinsertVarRecordsByVarName PROTOARGs((
-  CDFid id, char *varName, long startRec,long numRecs, void *buffer
+  CDFid id, char *varName, long startRec, long numRecs, void *buffer
+));
+VISIBLE_PREFIX CDFstatus CDFdeleteRecordsForAll PROTOARGs((
+  CDFid id, long startRec, long endRec
 ));
 VISIBLE_PREFIX void CDFsetFileBackward PROTOARGs((
   int flag
@@ -1751,6 +1782,12 @@ VISIBLE_PREFIX int CDFgetFileBackwardEnvVar PROTOARGs(());
 VISIBLE_PREFIX void CDFsetValidate PROTOARGs((long mode));
 VISIBLE_PREFIX int CDFgetValidate PROTOARGs(());
 VISIBLE_PREFIX int CDFgetValidateDebug PROTOARGs(());
+VISIBLE_PREFIX void ROWtoCOL PROTOARGs((
+  void *iBuffer, void *oBuffer, long numDims, long dimSizes[], long nValueBytes
+));
+VISIBLE_PREFIX void COLtoROW PROTOARGs((
+  void *iBuffer, void *oBuffer, long numDims, long dimSizes[], long nValueBytes
+));
 #if !defined(__CFM68K__) || defined(__USING_STATIC_LIBS__) || !defined(CFM68KDLL)
 VISIBLE_PREFIX void EPOCHbreakdown PROTOARGs((
   double epoch, long *year, long *month, long *day, long *hour, long *minute,
