@@ -77,6 +77,8 @@
 #define TT20002EPOCH16qual 30
 #define SORTqual        31
 #define BLOCKINGFACTORqual 32
+#define ADJUSTTT2000qual 33
+#define LEAPSECONDLASTUPDATEDqual 34
 
 /******************************************************************************
 * Macro constants.
