@@ -1,5 +1,5 @@
 /******************************************************************************
-* Copyright 1996-2013 United States Government as represented by the
+* Copyright 1996-2014 United States Government as represented by the
 * Administrator of the National Aeronautics and Space Administration.
 * All Rights Reserved.
 ******************************************************************************/
@@ -68,7 +68,7 @@ switch (Va->item) {
 #if defined(vms) || defined(dos)
     MakeUpperString (CDFpathT);
 #endif
-    if (!ValidCDFname(CDFpathT)) return BAD_CDF_NAME;
+/*  if (!ValidCDFname(CDFpathT)) return BAD_CDF_NAME; */
     if (!sX(FindCDF(CDFpathT,&no_append,
 		    &upper_case_ext,
 		    &version_numbers),&pStatus)) return pStatus;
@@ -544,6 +544,14 @@ switch (Va->item) {
     break;
   }
   /****************************************************************************
+  * CDF_LEAPSECONDLASTUPDATED_, 
+  ****************************************************************************/
+  case CDF_LEAPSECONDLASTUPDATED_: {
+    long *lastUpdated = va_arg (Va->ap, long *);
+    *lastUpdated = -1L;
+    break;
+  }
+  /****************************************************************************
   * rVAR_NAME_/zVAR_NAME_
   *    Note that a temporary variable is used when reading the variable name.
   * This is because the caller may have only allocated enough memory for the
