@@ -1,5 +1,5 @@
 /******************************************************************************
-* Copyright 1996-2013 United States Government as represented by the
+* Copyright 1996-2014 United States Government as represented by the
 * Administrator of the National Aeronautics and Space Administration.
 * All Rights Reserved.
 ******************************************************************************/
@@ -1129,8 +1129,10 @@ Logical deleteCDF;      /* Delete CDF file(s)? */
     /**************************************************************************
     * Close all of the CDF files if they are not already closed (or deleted).
     **************************************************************************/
-    if (CDF->dotFp != NULL) V_close64 (CDF->dotFp, CDF, NULL);
-    if (CDF->uDotFp != NULL) V_close64 (CDF->uDotFp, CDF, NULL);
+    if (CDF->dotFp != NULL) V_close64 (CDF->dotFp,
+				       ((updateCDF==UPDATE)?CDF:NULL), NULL);
+    if (CDF->uDotFp != NULL) V_close64 (CDF->uDotFp,
+				        ((updateCDF==UPDATE)?CDF:NULL), NULL);
     CloseVarFiles64 (CDF);
   }               
   /****************************************************************************
@@ -1410,3 +1412,54 @@ void *buffer;
   return CDF_OK;
 }
 
+/******************************************************************************
+* SetLeapSecondLastUpdate.
+* Set the last updated date for CDF that has TT2000 variable.
+******************************************************************************/
+
+STATICforIDL CDFstatus SetLeapSecondLastUpdate (CDF, Var, zVar)
+struct CDFstruct *CDF;
+struct VarStruct *Var;      /* the variable */
+Logical zVar;
+{
+  Int32 dataType, LeapSecondLastUpdated, version, release, increment;
+  long year, month, day;
+   CDFstatus pStatus = CDF_OK;
+  if (CDF->leapSecondUpdated == 1) return CDF_OK;
+  if (!sX(ReadVDR64(CDF,CDF->fp,Var->VDRoffset64,zVar,
+                    VDR_DATATYPE,&dataType,
+                    VDR_NULL),&pStatus)) {
+    AbortAccess64 (CDF, noUPDATE, noDELETE);
+    return pStatus;
+  }
+  if (dataType != CDF_TIME_TT2000) return CDF_OK;
+  if (!sX(ReadCDR64(CDF->fp,V3_CDR_OFFSET64,
+                    CDR_VERSION,&version,
+                    CDR_RELEASE,&release,
+                    CDR_INCREMENT,&increment,
+                    CDR_NULL),&pStatus)) {
+    AbortAccess64 (CDF, noUPDATE, noDELETE);
+    return pStatus;
+  }
+  /*********************************************************************
+  * Update version/release/increment and copywright only if a newer
+  * library version is modifying the CDF.
+  *********************************************************************/
+  if (!PriorTo("3.6.0",version,release,increment)) {
+#if defined(vms)
+    CDFgetLastDateinLeapSecondsTBL (&year, &month, &day);
+#else
+    CDFgetLastDateinLeapSecondsTable (&year, &month, &day);
+#endif
+    LeapSecondLastUpdated = (Int32) (10000*year + 100*month + day);
+    if (!sX(WriteGDR64(CDF->fp,CDF->GDRoffset64,
+                       GDR_LEAPSECONDLASTUPDATED,&LeapSecondLastUpdated,
+                       GDR_NULL),&pStatus)) {
+      AbortAccess64 (CDF, noUPDATE, DELETE);
+      cdf_FreeMemory (CDF, NULL);
+      return pStatus;
+    }
+    CDF->leapSecondUpdated = 1;
+  }
+  return CDF_OK;
+}
