@@ -91,7 +91,8 @@ static double  LTS [][6]= {
       { 1999,  1,   1, 32.0,             0.0, 0.0       },
       { 2006,  1,   1, 33.0,             0.0, 0.0       },
       { 2009,  1,   1, 34.0,             0.0, 0.0       },
-      { 2012,  7,   1, 35.0,             0.0, 0.0       }
+      { 2012,  7,   1, 35.0,             0.0, 0.0       },
+      { 2015,  7,   1, 36.0,             0.0, 0.0       }
      };
 
 /* Number of Delta(AT) in static table */
@@ -397,7 +398,7 @@ VISIBLE_PREFIX void CDFfillLeapSecondsTable (double **table)
 {
   int ix;
   if (LTD == NULL) LoadLeapSecondsTable();
-  for (ix = 0; ix < NDAT; ++ix) {
+  for (ix = 0; ix < entryCnt; ++ix) {
     table[ix][0] = LTD[ix][0];
     table[ix][1] = LTD[ix][1];
     table[ix][2] = LTD[ix][2];
@@ -494,19 +495,6 @@ va_dcl
     if (ix > 4) *opt[4] = 999.0;
     if (ix > 5) *opt[5] = 999.0;
     return;
-/*
-  } else if (nanoSecSinceJ2000 == ILLEGAL_TT2000_VALUE) {
-    *ly = 1710.0;
-    *lm = 1.0;
-    *ld = 1.0;
-    if (ix > 0) *opt[0] = 0.0;
-    if (ix > 1) *opt[1] = 0.0;
-    if (ix > 2) *opt[2] = 0.0;
-    if (ix > 3) *opt[3] = 0.0;
-    if (ix > 4) *opt[4] = 0.0;
-    if (ix > 5) *opt[5] = 0.0;
-    return;
-*/
   } else if (nanoSecSinceJ2000 == DEFAULT_TT2000_PADVALUE) {
     *ly = 0.0;
     *lm = 1.0;
@@ -522,19 +510,8 @@ va_dcl
   toPlus = 0;
   t3 = nanoSecSinceJ2000;
   dat0 = LeapSecondsfromJ2000 (nanoSecSinceJ2000, &leapSec);
-/*
-  nanoSecSinceJ2000 -= dTinNanoSecs;
-  nanoSecSinceJ2000 += T12hinNanoSecs;
-  t2 = nanoSecSinceJ2000;
-  secSinceJ2000 = (long long) ((double)nanoSecSinceJ2000/SECinNanoSecsD);
-  nansec = (long) (nanoSecSinceJ2000 - secSinceJ2000 * SECinNanoSecs);
-  if (nansec < 0) {
-    nansec = SECinNanoSecs + nansec;
-    --secSinceJ2000;
-  }
-*/
   if (nanoSecSinceJ2000 > 0) { /* try to avoid overflow (substraction first) */
-    secSinceJ2000 = (long) ((double)nanoSecSinceJ2000/SECinNanoSecsD);
+    secSinceJ2000 = (long long) ((double)nanoSecSinceJ2000/SECinNanoSecsD);
     nansec = (long) (nanoSecSinceJ2000 - secSinceJ2000 * SECinNanoSecs);
     secSinceJ2000 -= 32; /* secs portion in dT */
     secSinceJ2000 += 43200; /* secs in 12h */
@@ -542,7 +519,7 @@ va_dcl
   } else { /* try to avoid underflow (addition first) */
     nanoSecSinceJ2000 += T12hinNanoSecs; /* 12h in nanosecs */
     nanoSecSinceJ2000 -= dTinNanoSecs /* dT in nanosecs */;
-    secSinceJ2000 = (long) ((double)nanoSecSinceJ2000/SECinNanoSecsD);
+    secSinceJ2000 = (long long) ((double)nanoSecSinceJ2000/SECinNanoSecsD);
     nansec = (long) (nanoSecSinceJ2000 - secSinceJ2000 * SECinNanoSecs);
   }
   if (nansec < 0) {
@@ -1243,3 +1220,66 @@ VISIBLE_PREFIX void ReduceOpenCDFsCount ()
   if (openCDF64s == 0) CDFClearLeapSecondsTable();
 }
 
+/******************************************************************************
+* ValidateTT2000.
+* Retuens 1 if the TT2000 data is determined to be created properly based on
+* the info from the currently used leap second table, e.g., prior-to 2015/07/01
+* or leap second last updated being equal to the last entry in the table, or
+* the TT2000 time is within the next new leap second date.
+* It returns -1 if TT2000 time (based on an older leap second table) is after
+* a date that a new leap second was added. Or, the leap second table used by
+* the TT2000 time is even newer than the one currently being used. This is
+* considered a bad data or case. 
+* It returns 0 as we can't tell if the time is good. It's using pre-3.6.0 code
+* with the latest leap second table, which is good. But 
+* using the older table, which can be bad after 2015-07-01).
+******************************************************************************/
+
+VISIBLE_PREFIX int ValidateTT2000 (int tt2000YYYYMMDD,
+                                   int leapSecondLastUpdated)
+{
+  int i, last, lastDate;
+  if (tt2000YYYYMMDD < 20150701) return 1;
+  if (LTD == NULL) LoadLeapSecondsTable ();
+  last = entryCnt - 1;
+  lastDate = (int) (10000*LTD[last][0] + 100*LTD[last][1] + LTD[last][2]);
+  if (leapSecondLastUpdated == lastDate) return 1;
+  if (leapSecondLastUpdated > 0) {
+    if (tt2000YYYYMMDD < leapSecondLastUpdated) return 1;
+    if (lastDate > leapSecondLastUpdated) {
+      for (i = last-1; i >= 0; --i) {
+        if (leapSecondLastUpdated == (int) (10000*LTD[i][0] + 100*LTD[i][1] +
+                                            LTD[i][2])) {
+          if (tt2000YYYYMMDD < (int) (10000*LTD[i+1][0] + 100*LTD[i+1][1] +
+                                      LTD[i+1][2])) return 1;
+          else return -1;
+        }
+      }
+      return -1;
+    } else
+      return -1;
+  }
+  return 0;
+}
+
+/******************************************************************************
+* ValidateLeapSecondLastUpdated.
+* Retuens 1 if the passed date, in YYYYMMDD, is in the leap second table.
+* Otherwise, 0.
+******************************************************************************/
+
+VISIBLE_PREFIX int ValidateLeapSecondLastUpdated (int leapSecondLastUpdated)
+{
+  int i, last;
+  if (LTD == NULL) LoadLeapSecondsTable ();
+  last = entryCnt - 1;
+  for (i = last; i >= 0; --i) {
+    if (leapSecondLastUpdated == (int) (10000*LTD[i][0] + 100*LTD[i][1] +
+                                        LTD[i][2])) return 1;
+    if ((i < (last - 1)) && 
+        (leapSecondLastUpdated > (int) (10000*LTD[i+1][0] + 100*LTD[i+1][1] +
+                                        LTD[i+1][2]))) return 0;
+  }
+  return 0;
+}
+
