@@ -65,7 +65,7 @@ long numDims, dimSizes[CDF_MAX_DIMS], dimIntervals[CDF_MAX_DIMS],
      dimIndices[CDF_MAX_DIMS], dimCounts[CDF_MAX_DIMS];
 long version, release, increment, format, majority, encoding, numrVars,
      numzVars, numAttrs, numgAttrs, numvAttrs, numgEntries, numrEntries, 
-     numzEntries, checksum;
+     numzEntries, checksum, lastUpdated;
 long dataType, numElems, scope, recVary, dataTypeX, numElemsX;
 long dimVarys[CDF_MAX_DIMS];
 long compression, compressParms[CDF_MAX_DIMS], cPct;
@@ -342,7 +342,12 @@ switch (argC) {
       if (!PriorTo ("3.2.0", (Int32) version, (Int32) release,
 		    (Int32) increment)) 
       fprintf (fp, "Checksum:     %s\n", ChecksumToken(checksum));
-/*    } */
+      if (!PriorTo ("3.5.0", version, release, increment)) {
+        status = CDFlib (GET_, CDF_LEAPSECONDLASTUPDATED_, &lastUpdated,
+                         NULL_);
+        if (status < CDF_OK) QuitCDF (CDFpath, "2.1", status, CDFpath);
+        fprintf (fp, "LeapSecondLastUpdated:     %ld\n", lastUpdated);
+      }
   }
 
   /**********************************************/
@@ -647,7 +652,7 @@ switch (argC) {
     }
 
     if (!detect) {
-      fprintf (fp, "%s", varName);
+      fprintf (fp, "%s (%d)", varName, ii);
       if (METADATADUMP && compression != NO_COMPRESSION) {
         fprintf (fp, " (%s)\n",
                  CompressionToken(compression, compressParms));
@@ -744,7 +749,7 @@ switch (argC) {
             fprintf (fp, "Compression:         %s\n", 
                      CompressionToken(compression, compressParms));
           }
-        /* if (pad) { */
+        if (pad) {
           if (STRINGdataType(dataType)) {
             char delimiter;
             if (strchr(tText, '"') == NULL) delimiter = '"';
@@ -755,7 +760,7 @@ switch (argC) {
             fprintf (fp, "%c\n", delimiter);
           } else 
             if (!detect) fprintf (fp, "Pad value:           %s\n", tText);
-        /* } */
+        }
         fprintf (fp, "Written Records:     %ld/%ld(max)\n", numRecs, (maxRec+1));
         if (dump != DATADUMP) {
           fprintf (fp, "Allocated Records:   %ld/%ld(max)\n", numAllocRecs, 
