@@ -1224,6 +1224,7 @@ struct ItemWindowStruct *IW;
   long version, release, increment;
   long cType, cParms[CDF_MAX_PARMS], cPct;
   int pad;
+  long TT2000updated = -1L;
   /****************************************************************************
   * Encode label with name of CDF.
   ****************************************************************************/
@@ -1247,6 +1248,11 @@ struct ItemWindowStruct *IW;
 			 CDF_CHECKSUM_, &checksum,
 		   NULL_);
   if (!ReportStatus(status,FALSE)) return FALSE;
+  if (!PriorTo ("3.5.0", version, release, increment)) {
+    status = CDFlib (GET_, CDF_LEAPSECONDLASTUPDATED_, &TT2000updated,
+		     NULL_);
+    if (!ReportStatus(status,FALSE)) return FALSE;
+  }
   /****************************************************************************
   * Encode first line of header.
   ****************************************************************************/
@@ -1261,7 +1267,7 @@ struct ItemWindowStruct *IW;
   if (pad > 0) CatNcharacters (IW->hLines[0], pad, (int) ' ');
   snprintf (EofS(IW->hLines[0]),
 	    (size_t) sizeof(BLANKs78)-strlen(IW->hLines[0]),
-	    "Compression: %s", CompressionToken(cType,cParms));
+	    "Compression:    %s", CompressionToken(cType,cParms));
 #if 0
   if (cType != NO_COMPRESSION && cPct > 0) {
     snprintf (EofS(IW->hLines[0]),
@@ -1283,7 +1289,7 @@ struct ItemWindowStruct *IW;
   if (pad > 0) CatNcharacters (IW->hLines[1], pad, (int) ' ');
   snprintf (EofS(IW->hLines[1]),
 	    (size_t) sizeof(BLANKs78)-strlen(IW->hLines[1]),
-	    "Encoding:    %s", EncodingToken(encoding));
+	    "Encoding:       %s", EncodingToken(encoding));
   /****************************************************************************
   * Encode third line of header.
   ****************************************************************************/
@@ -1294,6 +1300,13 @@ struct ItemWindowStruct *IW;
   snprintf (EofS(IW->hLines[2]),
 	    (size_t) sizeof(BLANKs78)-strlen(IW->hLines[2]),
 	    "Checksum:   %s", ChecksumToken(checksum));
+  if (TT2000updated >= 0) {
+    pad = MAIN_MENU_2nd_THIRD_LEN - strlen(IW->hLines[2]);
+    if (pad > 0) CatNcharacters (IW->hLines[2], pad, (int) ' ');
+    snprintf (EofS(IW->hLines[2]),
+              (size_t) sizeof(BLANKs78)-strlen(IW->hLines[2]),
+              "LastLeapSecond: %d", (int) TT2000updated);
+  }
   return TRUE;
 }
 
